@@ -45,6 +45,7 @@ class NaturalPersonEditPersonalDataView(EditView):
         "autogenerate_displayname",
         "first_name",
         "last_name",
+        "maiden_name",
         "gender",
         "date_of_birth",
         "place_of_birth",
@@ -87,6 +88,7 @@ class NaturalPersonEditPersonalDataView(EditView):
                 ),
                 R(C(F("first_name"))),
                 R(C(F("last_name"))),
+                R(C(F("maiden_name"))),
                 R(C(F("gender"))),
                 R(C(F("date_of_birth"))),
                 R(C(F("place_of_birth"))),
@@ -126,11 +128,11 @@ class LegalPersonEditMailingsView(EditView):
 class EditPostalAddressView(EditView):
     model = models.Postal
     fields = [
-        "type",
         "address",
         "postcode",
         "city",
         "country",
+        "type",
         "valid_from",
         "valid_until",
     ]
@@ -176,7 +178,7 @@ class AddPostalAddressView(AddView):
 
 class EditEmailAddressView(EditView):
     model = models.Email
-    fields = ["type", "email"]
+    fields = ["email", "type"]
 
     def form_valid(self, form, *args, **kwargs):
 
