@@ -1,4 +1,4 @@
-from bread.contrib.languages.fields import LanguageField
+from basxbread.contrib.languages.fields import LanguageField
 from django.db import models
 from django.utils.translation import gettext_lazy as _
 
